pytest skippy
=============

Automatically skip tests that don't need to run!

This library works with pytest to generate a complete import graph for your
tests. If nothing in the import graph has changed (according to GIT), the test
is skipped.

.. toctree::
   :maxdepth: 2

    Quickstart <quickstart>
    User Guide <userguide>
    Limitations <limitations>
    API <pytest_skippy>
